@@ -9,7 +9,8 @@
 
 from detector_connector import DetectorConnector
 
-from .obstruction_analyze_result import ObstructionAnalyzeResult
+from obstruction_detector_connector.obstruction_analyze_result import ObstructionAnalyzeResult
+from obstruction_detector_connector.obstruction_settings import ObstructionSettings
 
 
 class ObstructionDetectorConnector(DetectorConnector):
@@ -17,4 +18,7 @@ class ObstructionDetectorConnector(DetectorConnector):
     Config = DetectorConnector.Config
 
     def __init__(self, config: Config, context: Context):
-        super().__init__(config=config, context=context, detector_analyze_result_type=ObstructionAnalyzeResult)
+        super().__init__(config=config,
+                         context=context,
+                         detector_analyze_result_type=ObstructionAnalyzeResult,
+                         detector_settings_type=ObstructionSettings)
